library(MASS)

# Create data frame (this comes from processing of huge datafiles, reproduced here as just the data used for model fitting)

lat <- 15:49 # latitude degrees over which we have data
pba <- c(0.037342396, 0.134907756, 0.071779830, 0.100324484, 0.112885805, 0.178904449,
	0.165263284, 0.048426153, 0.071682012, 0.119959536, 0.032593708, 0.048388639,
	0.187462712, 0.264285184, 0.125963993, 0.008966556, 0.079734127, 0.144186790,
	0.113818174, 0.063536272, 0.038213305, 0.007629484, 0.005245335, 0.010508669,
	0.018035527, 0.011986188, 0.023402568, 0.011454780, 0.004679852, 0.006854592,
	0.005741661, 0.010246540, 0.009645471, 0.007261736, 0.007961923)
latdata <- data.frame(lat,pba)

logit <- 1
logstp <- 1
logitfn <- function(vec) logitvec <- log(vec/(1-vec))
alogitfn <- function(vec) alogitvec <- 1/(1+exp(-vec))

# The following modeled data are imported from matlab
# They represent the sum of biomass over succession, weighted by the FIA stand age distribution or half or twice that
latcut <- 35 # used for cutoff between high latitude and low latitude age distributions
agedist_h <- 1 # 1 for FIA, 2 for half, 3 for double
agedist_l <- 1 # 1 for FIA, 2 for half, 3 for double
# Change these and rerun following code to get Ecological Archives figures
if(agedist_h==1){
	sevob_Nfix <- rep(185.4526,nrow(latdata)) # Obligate N fixer, primary succession
	sevob_nonfix <- rep(8143.0,nrow(latdata)) # Non-fixer (vs. obligate), primary succession
	modob_Nfix <- rep(148.8449,nrow(latdata)) # Obligate, secondary succession
	modob_nonfix <- rep(9676.0,nrow(latdata)) # Non-fixer (vs. obligate), secondary
	sevfac_Nfix <- rep(7450.2,nrow(latdata)) # Facultative N fixer, primary
	sevfac_nonfix <- rep(605.4491,nrow(latdata)) # Non-fixer (vs. facultative), primary
	modfac_Nfix <- rep(5899.0,nrow(latdata)) # Facultative N fixer, secondary
	modfac_nonfix <- rep(3711.8,nrow(latdata)) # Facultative N fixer, secondary
	print('High latitudes have FIA age distribution')
}else if(agedist_h==2){
	sevob_Nfix <- rep(250.0038,nrow(latdata)) # Obligate N fixer, primary succession
	sevob_nonfix <- rep(4415.9,nrow(latdata)) # Non-fixer (vs. obligate), primary succession
	modob_Nfix <- rep(174.1365,nrow(latdata)) # Obligate, secondary succession
	modob_nonfix <- rep(6030.5,nrow(latdata)) # Non-fixer (vs. obligate), secondary
	sevfac_Nfix <- rep(4423.3,nrow(latdata)) # Facultative N fixer, primary
	sevfac_nonfix <- rep(82.8596,nrow(latdata)) # Non-fixer (vs. facultative), primary
	modfac_Nfix <- rep(4445.5,nrow(latdata)) # Facultative N fixer, secondary
	modfac_nonfix <- rep(1592.2,nrow(latdata)) # Facultative N fixer, secondary
	print('High latitudes have half the FIA age distribution')
}else if(agedist_h==3){
	sevob_Nfix <- rep(150.6092,nrow(latdata)) # Obligate N fixer, primary succession
	sevob_nonfix <- rep(13828,nrow(latdata)) # Non-fixer (vs. obligate), primary succession
	modob_Nfix <- rep(133.0752,nrow(latdata)) # Obligate, secondary succession
	modob_nonfix <- rep(15263,nrow(latdata)) # Non-fixer (vs. obligate), secondary
	sevfac_Nfix <- rep(10485,nrow(latdata)) # Facultative N fixer, primary
	sevfac_nonfix <- rep(3185.5,nrow(latdata)) # Non-fixer (vs. facultative), primary
	modfac_Nfix <- rep(6194.6,nrow(latdata)) # Facultative N fixer, secondary
	modfac_nonfix <- rep(9048.2,nrow(latdata)) # Facultative N fixer, secondary
	print('High latitudes have double the FIA age distribution')
}
if(agedist_l==1){
	sevob_Nfix[latdata$lat<=latcut] <- rep(185.4526,nrow(latdata[latdata$lat<=latcut,]))
	sevob_nonfix[latdata$lat<=latcut] <- rep(8143.0,nrow(latdata[latdata$lat<=latcut,]))
	modob_Nfix[latdata$lat<=latcut] <- rep(148.8449,nrow(latdata[latdata$lat<=latcut,]))
	modob_nonfix[latdata$lat<=latcut] <- rep(9676.0,nrow(latdata[latdata$lat<=latcut,]))
	sevfac_Nfix[latdata$lat<=latcut] <- rep(7450.2,nrow(latdata[latdata$lat<=latcut,]))
	sevfac_nonfix[latdata$lat<=latcut] <- rep(605.4491,nrow(latdata[latdata$lat<=latcut,]))
	modfac_Nfix[latdata$lat<=latcut] <- rep(5899.0,nrow(latdata[latdata$lat<=latcut,]))
	modfac_nonfix[latdata$lat<=latcut] <- rep(3711.8,nrow(latdata[latdata$lat<=latcut,]))
	print('Low latitudes have the FIA age distribution')
}else if(agedist_l==2){
	sevob_Nfix[latdata$lat<=latcut] <- rep(250.0038,nrow(latdata[latdata$lat<=latcut,]))
	sevob_nonfix[latdata$lat<=latcut] <- rep(4415.9,nrow(latdata[latdata$lat<=latcut,]))
	modob_Nfix[latdata$lat<=latcut] <- rep(174.1365,nrow(latdata[latdata$lat<=latcut,]))
	modob_nonfix[latdata$lat<=latcut] <- rep(6030.5,nrow(latdata[latdata$lat<=latcut,]))
	sevfac_Nfix[latdata$lat<=latcut] <- rep(4423.3,nrow(latdata[latdata$lat<=latcut,]))
	sevfac_nonfix[latdata$lat<=latcut] <- rep(82.8596,nrow(latdata[latdata$lat<=latcut,]))
	modfac_Nfix[latdata$lat<=latcut] <- rep(4445.5,nrow(latdata[latdata$lat<=latcut,]))
	modfac_nonfix[latdata$lat<=latcut] <- rep(1592.2,nrow(latdata[latdata$lat<=latcut,]))
	print('Low latitudes have half the FIA age distribution')
}else if(agedist_l==3){
	sevob_Nfix[latdata$lat<=latcut] <- rep(150.6092,nrow(latdata[latdata$lat<=latcut,]))
	sevob_nonfix[latdata$lat<=latcut] <- rep(13828,nrow(latdata[latdata$lat<=latcut,]))
	modob_Nfix[latdata$lat<=latcut] <- rep(133.0752,nrow(latdata[latdata$lat<=latcut,]))
	modob_nonfix[latdata$lat<=latcut] <- rep(15263,nrow(latdata[latdata$lat<=latcut,]))
	sevfac_Nfix[latdata$lat<=latcut] <- rep(10485,nrow(latdata[latdata$lat<=latcut,]))
	sevfac_nonfix[latdata$lat<=latcut] <- rep(3185.5,nrow(latdata[latdata$lat<=latcut,]))
	modfac_Nfix[latdata$lat<=latcut] <- rep(6194.6,nrow(latdata[latdata$lat<=latcut,]))
	modfac_nonfix[latdata$lat<=latcut] <- rep(9048.2,nrow(latdata[latdata$lat<=latcut,]))
	print('Low latitudes have double the FIA age distribution')
}
notob_Nfix <- rep(0,nrow(latdata))
notob_nonfix <- modob_Nfix + modob_nonfix
notfac_Nfix <- rep(0,nrow(latdata))
notfac_nonfix <- modob_Nfix + modob_nonfix
print(round(sevob_Nfix/(sevob_Nfix+sevob_nonfix)*1000)/10)
print(round(modob_Nfix/(modob_Nfix+modob_nonfix)*1000)/10)
print(round(sevfac_Nfix/(sevfac_Nfix+sevfac_nonfix)*100))
print(round(modfac_Nfix/(modfac_Nfix+modfac_nonfix)*100))

# Starting values
SevInf <- 38 # Normally 38, switch to 34 to get model 4 convergence for agedist_h = 2, agedist_l = 1; 32 or 33 for h2,l1
SevMin <- 0.01
SevMax <- 0.03
SevStp <- 0.95
ModMin <- 0.1
ModMax <- 0.9
ObInf <- 34 # Normally 34, switch to 34.5 to get convergence for model 4 when agedist_h = 1, agedist_l = 3; 32 to get convergence for h2,l3
ObMin <- 0.1
ObMax <- 0.9
ObStp <- 1.1

sigmoid <- function(p,fixed,x){ 	# p1 inflection, p2 min, p3 max, p4 steepness (+ for up, - for down)
						# call with p vector that has this order regardless what's fixed, e.g., if min is fixed, p should be inflection, max, steepness
						# fixed tells the function whether each parameter is fixed (> -999) or not (-999)
	p1 <- p[1] # Never fixed, so fixed[1] doesn't matter
	if(fixed[2]< -900) { # if min is not fixed
		p2 <- p[2]
		if(fixed[3]< -900){ # if max is not fixed
			p3 <- p[3]
			if(fixed[4]< -900) p4 <- p[4] else p4 <- fixed[4] # 1 or -1
		}else{ # if max is fixed
			p3 <- fixed[3]
			if(fixed[4]< -900) p4 <- p[3] else p4 <- fixed[4]
		}
	}else{ # if min is fixed
		p2 <- fixed[2]
		if(fixed[3]< -900){ # if max is not fixed
			p3 <- p[2]
			if(fixed[4]< -900) p4 <- p[3] else p4 <- fixed[4]
		}else{ # if max is fixed
			p3 <- fixed[3]
			if(fixed[4]< -900) p4 <- p[2] else p4 <- fixed[4]
		}
	}
	if(logit==1 & fixed[2]< -900){
		p2 <- alogitfn(p2)
	}
	if(logit==1 & fixed[3] < -900){
		p3 <- alogitfn(p3)
	}
	if(logstp==1 & fixed[4] < -900){
		p4 <- exp(p4)
	}
	y <- p2 + (p3-p2)/(1+exp(-p4*(x-p1)))
}

latmodelfn <- function(p,sevfixed,modfixed,obfixed,x) { 
	sevpsfixed <- length(sevfixed[sevfixed> -900])
	Severe <- sigmoid(p[1:(4-sevpsfixed)],sevfixed,x)
	modpsfixed <- length(modfixed[modfixed>-900])
	if(modpsfixed==3){
		Moderate <- sigmoid(p[1],modfixed,x)
	}else if(modpsfixed==0){
		Moderate <- sigmoid(c(p[1],p[(5-sevpsfixed):(6-sevpsfixed)],p[4-sevpsfixed]),modfixed,x)
	}else if(modfixed[2]> -900){
		if(modfixed[3]> -900){ 								# 2 and 3 fixed
			Moderate <- sigmoid(c(p[1],p[4-sevpsfixed]),modfixed,x)
		}else if(modfixed[4]> -900){ 							# 2 and 4 fixed
			Moderate <- sigmoid(c(p[1],p[5-sevpsfixed]),modfixed,x)
		}else Moderate <- sigmoid(c(p[1],p[5-sevpsfixed],p[4-sevpsfixed]),modfixed,x)	# 2 only fixed
	}else if(modfixed[3]> -900){
		if(modfixed[4]> -900){ 								# 3 and 4 fixed
			Moderate <- sigmoid(c(p[1],p[5-sevpsfixed]),modfixed,x)
		}else Moderate <- sigmoid(c(p[1],p[5-sevpsfixed],p[4-sevpsfixed]),modfixed,x)	# 3 only fixed
	}else Moderate <- sigmoid(c(p[1],p[5-sevpsfixed],p[6-sevpsfixed]),modfixed,x)					# 4 only fixed
	Non <- 1 - Severe - Moderate
	obpsfixed <- length(obfixed[obfixed>-900])
	realmodfixed <- modfixed[2:3]
	realmodpsfixed <- length(realmodfixed[realmodfixed>-900])
	Ob <- sigmoid(p[(7-sevpsfixed-realmodpsfixed):(10-sevpsfixed-realmodpsfixed-obpsfixed)],obfixed,x)
	if(obfixed[1] > 1000){
		Ob <- alogitfn(p[(7-sevpsfixed-realmodpsfixed)])
	}
	Fac <- 1 - Ob
	Nfixer <- Ob*(Severe*sevob_Nfix + Moderate*modob_Nfix + Non*notob_Nfix) + Fac*(Severe*sevfac_Nfix + Moderate*modfac_Nfix + Non*notfac_Nfix)
	Nonfixer <- Ob*(Severe*sevob_nonfix + Moderate*modob_nonfix + Non*notob_nonfix) + Fac*(Severe*sevfac_nonfix + Moderate*modfac_nonfix + Non*notfac_nonfix)
	Nfixer <- Ob*(Severe*sevob_Nfix + Moderate*modob_Nfix + Non*notob_Nfix) + Fac*(Severe*sevfac_Nfix + Moderate*modfac_Nfix + Non*notfac_Nfix)
	Nonfixer <- Ob*(Severe*sevob_nonfix + Moderate*modob_nonfix + Non*notob_nonfix) + Fac*(Severe*sevfac_nonfix + Moderate*modfac_nonfix + Non*notfac_nonfix)
	PercentNfix <- Nfixer/(Nonfixer+Nfixer)
}

AICc <- function(fitobj){
	K <- length(coef(fitobj))+1
	n <- K-1+df.residual(fitobj)
	AICc <- AIC(fitobj) + 2*K*(K+1)/(n-K-1)
}

deltaAICs <- function(AICvec){
	for(i in 1:length(AICvec)){
		print(AICvec[i]-min(AICvec))
	}
}

# Simple sigmoid fit to data
sigfixed <- c(-999,-999,-999,-999)
if(logit==1 & logstp==1){
	print(summary(sigfit <- nls(pba~sigmoid(p,sigfixed,lat),data=latdata,algorithm="port",start=list(p=c(35,logitfn(0.11),logitfn(0.01),log(1))),lower=c(16,logitfn(0.0000001),logitfn(0.0000001),log(0.0000001),upper=c(48,logitfn(0.9999999),logitfn(0.9999999),log(100))))))
}else if(logit==1 & logstp!=1){
	print(summary(sigfit <- nls(pba~sigmoid(p,sigfixed,lat),data=latdata,algorithm="port",start=list(p=c(35,logitfn(0.11),logitfn(0.01),1)),lower=c(16,logitfn(0.0000001),logitfn(0.0000001),0.0000001,upper=c(48,logitfn(0.9999999),logitfn(0.9999999),100)))))
}else{
	print(summary(sigfit <- nls(pba~sigmoid(p,sigfixed,lat),data=latdata,algorithm="port",start=list(p=c(35,0.01,0.1,-1)),lower=c(16,0,0,-100),upper=c(48,1,1,100))))
}
print(summary(linfit <- lm(latdata$pba ~ latdata$lat)))

deltaAICs(c(AICc(sigfit),AICc(linfit)))

# Model fit to data
tval <- TRUE # Used to control whether trace is output for each fit
minobfixed <- 0.0 # Change to 0.1 for one supplemental figure in Ecological Archive
maxobfixed <- 1.0

# These are the various version of the model with different numbers of free parameters
# -999 means free; anything else means fixed
# 4 and 5 are the models used in the main text, 8 and 9 are in the Ecological Archives
sevfixed4 <- c(-999,-999,-999,1) # severely N-limited, steepness fixed at 1
modfixed4 <- c(-999,0,0,1) # set to 0 to specify no moderately N-limited
obfixed4 <- c(-999,minobfixed,maxobfixed,1) # percent obligate latitude is free, minimum and maximum and steepness are fixed
print(summary(modelfit4 <- nls(pba~latmodelfn(p,sevfixed4,modfixed4,obfixed4,lat),data=latdata,trace=tval,algorithm="port",start=list(p=c(SevInf,logitfn(SevMin),logitfn(SevMax),ObInf)),lower=c(16,logitfn(0.0000001),logitfn(0.0000001),16),upper=c(48,logitfn(0.9999999),logitfn(0.9999999),48))))
sevfixed5 <- c(-999,0,0,1)
modfixed5 <- c(-999,-999,-999,1)
obfixed5 <- c(-999,minobfixed,maxobfixed,1)
print(summary(modelfit5 <- nls(pba~latmodelfn(p,sevfixed5,modfixed5,obfixed5,lat),data=latdata,trace=tval,algorithm="port",start=list(p=c(SevInf,logitfn(ModMin),logitfn(ModMax),ObInf)),lower=c(16,logitfn(0.0000001),logitfn(0.0000001),16),upper=c(48,logitfn(0.9999999),logitfn(0.9999999),48))))
sevfixed8 <- c(-999,0,0,1)
modfixed8 <- c(-999,-999,-999,1)
obfixed8 <- c(-999,minobfixed,maxobfixed,-999)
print(summary(modelfit8 <- nls(pba~latmodelfn(p,sevfixed8,modfixed8,obfixed8,lat),data=latdata,trace=tval,algorithm="port",start=list(p=c(SevInf,logitfn(ModMin),logitfn(ModMax),ObInf,log(ObStp))),lower=c(16,logitfn(0.0000001),logitfn(0.0000001),16,log(0.0000001)),upper=c(48,logitfn(0.9999999),logitfn(0.9999999),48,log(100)))))
sevfixed9 <- c(-999,-999,-999,1)
modfixed9 <- c(-999,0,0,1)
obfixed9 <- c(-999,minobfixed,maxobfixed,-999)
print(summary(modelfit9 <- nls(pba~latmodelfn(p,sevfixed9,modfixed9,obfixed9,lat),data=latdata,trace=tval,algorithm="port",start=list(p=c(SevInf,logitfn(SevMin),logitfn(SevMax),ObInf,log(ObStp))),lower=c(16,logitfn(0.0000001),logitfn(0.0000001),16,log(0.1)),upper=c(48,logitfn(0.9999999),logitfn(0.9999999),48,log(100)))))

# print out delta AICc values for nonmechanistic sigmoid fit, nonmechanistic linear fit, and models 4,5,8,9
deltaAICs(c(AICc(sigfit),AICc(linfit),AICc(modelfit4),AICc(modelfit5),AICc(modelfit8),AICc(modelfit9)))

printout4 <- TRUE # Change these to control which one is printed
printout5 <- TRUE
printout9 <- FALSE
printout8 <- FALSE
printout10 <- FALSE
printout11 <- FALSE
printout14 <- FALSE
cifactor <- 1.96
if(printout4){
	ps <- summary(modelfit4)$parameters
	print(paste("c1,sev =",alogitfn(ps[2,1]),"(",alogitfn(ps[2,1]-cifactor*ps[2,2]),"-",alogitfn(ps[2,1]+cifactor*ps[2,2]),")"))
	print(paste("c2,sev =",alogitfn(ps[3,1]),"(",alogitfn(ps[3,1]-cifactor*ps[3,2]),"-",alogitfn(ps[3,1]+cifactor*ps[3,2]),")"))
	print(paste("c4,sev =",ps[1,1],"(",ps[1,1]-cifactor*ps[1,2],"-",ps[1,1]+cifactor*ps[1,2],")"))
	print(paste("c4,ob =",ps[4,1],"(",ps[4,1]-cifactor*ps[4,2],"-",ps[4,1]+cifactor*ps[4,2],")"))
}
if(printout5){
	ps <- summary(modelfit5)$parameters
	print(paste("c1,mod =",alogitfn(ps[2,1]),"(",alogitfn(ps[2,1]-cifactor*ps[2,2]),"-",alogitfn(ps[2,1]+cifactor*ps[2,2]),")"))
	print(paste("c2,mod =",alogitfn(ps[3,1]),"(",alogitfn(ps[3,1]-cifactor*ps[3,2]),"-",alogitfn(ps[3,1]+cifactor*ps[3,2]),")"))
	print(paste("c4,mod =",ps[1,1],"(",ps[1,1]-cifactor*ps[1,2],"-",ps[1,1]+cifactor*ps[1,2],")"))
	print(paste("c4,ob =",ps[4,1],"(",ps[4,1]-cifactor*ps[4,2],"-",ps[4,1]+cifactor*ps[4,2],")"))
}
if(printout9){
	ps <- summary(modelfit9)$parameters
	print(paste("c1,sev =",alogitfn(ps[2,1]),"(",alogitfn(ps[2,1]-cifactor*ps[2,2]),"-",alogitfn(ps[2,1]+cifactor*ps[2,2]),")"))
	print(paste("c2,sev =",alogitfn(ps[3,1]),"(",alogitfn(ps[3,1]-cifactor*ps[3,2]),"-",alogitfn(ps[3,1]+cifactor*ps[3,2]),")"))
	print(paste("c4,sev =",ps[1,1],"(",ps[1,1]-cifactor*ps[1,2],"-",ps[1,1]+cifactor*ps[1,2],")"))
	print(paste("c3,ob =",exp(ps[5,1]),"(",exp(ps[5,1]-cifactor*ps[5,2]),"-",exp(ps[5,1]+cifactor*ps[5,2]),")"))
	print(paste("c4,ob =",ps[4,1],"(",ps[4,1]-cifactor*ps[4,2],"-",ps[4,1]+cifactor*ps[4,2],")"))
}
if(printout8){
	ps <- summary(modelfit8)$parameters
	print(paste("c1,mod =",alogitfn(ps[2,1]),"(",alogitfn(ps[2,1]-cifactor*ps[2,2]),"-",alogitfn(ps[2,1]+cifactor*ps[2,2]),")"))
	print(paste("c2,mod =",alogitfn(ps[3,1]),"(",alogitfn(ps[3,1]-cifactor*ps[3,2]),"-",alogitfn(ps[3,1]+cifactor*ps[3,2]),")"))
	print(paste("c4,mod =",ps[1,1],"(",ps[1,1]-cifactor*ps[1,2],"-",ps[1,1]+cifactor*ps[1,2],")"))
	print(paste("c3,ob =",exp(ps[5,1]),"(",exp(ps[5,1]-cifactor*ps[5,2]),"-",exp(ps[5,1]+cifactor*ps[5,2]),")"))
	print(paste("c4,ob =",ps[4,1],"(",ps[4,1]-cifactor*ps[4,2],"-",ps[4,1]+cifactor*ps[4,2],")"))
}

# Plot
graphics.off() # turn off any open graphical devices
fig.width<-93/25.4 # width of figures (inches)
fig.ht<-140/25.4 # height (inches)
windows(width = fig.width, height = fig.ht, pointsize = 12, record=TRUE)

n.row<-3 # number of rows in figures
n.col<-1 # number of columns
par(mfrow=c(n.row,n.col),mgp=c(1.5,0.5,0),mar=c(3,3,2,2),oma=c(0,0,0,2)) # set plotting parameters

axc <- 1.4

# PANEL A

### This follows the method in Bolker's book section 7.5.3 to get 95% CIs on the curves

ndraws <- 1000
latxs <- 15:49
cis <- 0.95
lowb <- 0.5-(cis/2)
upb <- 0.5+(cis/2)
cilinetype <- 2
cilinewidth <- 2

mod4 <- TRUE # change these to plot different fits
mod5 <- TRUE
mod8 <- FALSE
mod9 <- FALSE
sigmod <- FALSE
first <- TRUE # needs to be "TRUE" to start to plot the right things
if(mod4==TRUE){
	vmat_A4 <- mvrnorm(ndraws,mu=coef(modelfit4)[4],Sigma=vcov(modelfit4)[4,4])
	dist_A4 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
			dist_A4[i,] <- sigmoid(vmat_A4[i,],obfixed4,latxs)*100
	}
	civec_A4 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_A4[,j] <- quantile(dist_A4[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(modelfit4)[4],obfixed4,x)*100,15,49,lwd=3,xlab="",ylab="% N fixers obligate",xlim=c(15,49),ylim=c(0,100),cex.axis=axc,cex.lab=axc,col="gray",add=!first)
	points(latxs,civec_A4[1,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_A4[2,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	mtext('(a)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}
if(mod5==TRUE){
	vmat_A5 <- mvrnorm(ndraws,mu=coef(modelfit5)[4],Sigma=vcov(modelfit5)[4,4])
	dist_A5 <- array(dim=c(ndraws,length(latxs)))
		for(i in 1:ndraws){
		dist_A5[i,] <- sigmoid(vmat_A5[i,],obfixed5,latxs)*100
	}
	civec_A5 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_A5[,j] <- quantile(dist_A5[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(modelfit5)[4],obfixed5,x)*100,15,49,lwd=3,lty=1,add=!first,col="black",xlab="",ylab="% N fixers obligate",xlim=c(15,49),ylim=c(0,100),cex.axis=axc,cex.lab=axc,)
	points(latxs,civec_A5[1,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_A5[2,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	mtext('(a)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}
if(mod9==TRUE){
	vmat_A9 <- mvrnorm(ndraws,mu=coef(modelfit9)[4:5],Sigma=vcov(modelfit9)[4:5,4:5])
	dist_A9 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
			dist_A9[i,] <- sigmoid(vmat_A9[i,],obfixed9,latxs)*100
	}
	civec_A9 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_A9[,j] <- quantile(dist_A9[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(modelfit9)[4:5],obfixed9,x)*100,15,49,lwd=3,xlab="",ylab="% N fixers obligate",xlim=c(15,49),ylim=c(0,100),cex.axis=axc,cex.lab=axc,col="gray",add=!first)
	points(latxs,civec_A9[1,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_A9[2,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	mtext('(a)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}
if(mod8==TRUE){
	vmat_A8 <- mvrnorm(ndraws,mu=coef(modelfit8)[4:5],Sigma=vcov(modelfit8)[4:5,4:5])
	dist_A8 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_A8[i,] <- sigmoid(vmat_A8[i,],obfixed8,latxs)*100
	}
	civec_A8 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_A8[,j] <- quantile(dist_A8[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(modelfit8)[4:5],obfixed8,x)*100,15,49,lwd=3,lty=1,add=!first,col="black",xlab="",ylab="% habitat N limited",xlim=c(15,49),ylim=c(0,100),cex.axis=axc,cex.lab=axc)
	points(latxs,civec_A8[1,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_A8[2,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	mtext('(a)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}

# PANEL B

first <- TRUE
if(mod4==TRUE){
	vmat_B4 <- mvrnorm(ndraws,mu=coef(modelfit4)[1:3],Sigma=vcov(modelfit4)[1:3,1:3])
	dist_B4 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_B4[i,] <- sigmoid(vmat_B4[i,],sevfixed4,latxs)*100
	}
	civec_B4 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_B4[,j] <- quantile(dist_B4[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(modelfit4)[1:3],sevfixed4,x)*100,15,49,lwd=3,xlab="",ylab="% habitat N limited",xlim=c(15,49),lty=1,ylim=c(0,100),cex.axis=axc,cex.lab=axc,col="gray",add=!first)
	points(latxs,civec_B4[1,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_B4[2,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	mtext('(b)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}
if(mod5==TRUE){
	vmat_B5 <- mvrnorm(ndraws,mu=coef(modelfit5)[1:3],Sigma=vcov(modelfit5)[1:3,1:3])
	dist_B5 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_B5[i,] <- sigmoid(vmat_B5[i,],modfixed5,latxs)*100
	}
	civec_B5 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_B5[,j] <- quantile(dist_B5[,j],c(lowb,upb),na.rm=TRUE)
	}
	
	curve(sigmoid(coef(modelfit5)[1:3],modfixed5,x)*100,15,49,lwd=3,add=!first,col="black",xlab="",ylab="% habitat N limited",xlim=c(15,49),lty=1,ylim=c(0,100),cex.axis=axc,cex.lab=axc)
	points(latxs,civec_B5[1,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_B5[2,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	mtext('(b)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}
if(mod9==TRUE){
	vmat_B9 <- mvrnorm(ndraws,mu=coef(modelfit9)[1:3],Sigma=vcov(modelfit9)[1:3,1:3])
	dist_B9 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_B9[i,] <- sigmoid(vmat_B9[i,],sevfixed9,latxs)*100
	}
	civec_B9 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_B9[,j] <- quantile(dist_B9[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(modelfit9)[1:3],sevfixed9,x)*100,15,49,lwd=3,xlab="",ylab="% habitat N limited",xlim=c(15,49),lty=1,ylim=c(0,100),cex.axis=axc,cex.lab=axc,col="gray",add=!first)
	points(latxs,civec_B9[1,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_B9[2,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	mtext('(b)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}
if(mod8==TRUE){
	vmat_B8 <- mvrnorm(ndraws,mu=coef(modelfit8)[1:3],Sigma=vcov(modelfit8)[1:3,1:3])
	dist_B8 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_B8[i,] <- sigmoid(vmat_B8[i,],modfixed8,latxs)*100
	}
	civec_B8 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_B8[,j] <- quantile(dist_B8[,j],c(lowb,upb),na.rm=TRUE)
	}
	
	curve(sigmoid(c(coef(modelfit8)[1:3]),modfixed8,x)*100,15,49,lwd=3,add=!first,col="black",xlab="",ylab="% habitat N limited",xlim=c(15,49),lty=1,ylim=c(0,100),cex.axis=axc,cex.lab=axc)
	points(latxs,civec_B8[1,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_B8[2,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	mtext('(b)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)
	first <- FALSE
}

# PANEL C

plot(lat,pba*100,pch=19,cex=2,col="black",xlab="Latitude",ylab="N fixer basal area %",xlim=c(15,49),cex.axis=axc,cex.lab=axc,ylim=c(0,30))
mtext('(c)',side=3,font=2,cex=1.3,adj=0,padj=-0.3)

if(mod4==TRUE){
	vmat_C4 <- mvrnorm(ndraws,mu=coef(modelfit4),Sigma=vcov(modelfit4))
	dist_C4 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_C4[i,] <- latmodelfn(vmat_C4[i,],sevfixed4,modfixed4,obfixed4,latxs)*100
	}
	civec_C4 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_C4[,j] <- quantile(dist_C4[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(latmodelfn(coef(modelfit4),sevfixed4,modfixed4,obfixed4,x)*100,15,49,n=length(latxs),add=TRUE,lwd=3,col="gray")
	points(latxs,civec_C4[1,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_C4[2,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
}
if(mod5==TRUE){
	vmat_C5 <- mvrnorm(ndraws,mu=coef(modelfit5),Sigma=vcov(modelfit5))
	dist_C5 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_C5[i,] <- latmodelfn(vmat_C5[i,],sevfixed5,modfixed5,obfixed5,latxs)*100
	}
	civec_C5 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_C5[,j] <- quantile(dist_C5[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(latmodelfn(coef(modelfit5),sevfixed5,modfixed5,obfixed5,x)*100,15,49,n=length(latxs),add=TRUE,lwd=3,col="black")
	points(latxs,civec_C5[1,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_C5[2,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
}
if(mod9==TRUE){
	vmat_C9 <- mvrnorm(ndraws,mu=coef(modelfit9),Sigma=vcov(modelfit9))
	dist_C9 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_C9[i,] <- latmodelfn(vmat_C9[i,],sevfixed9,modfixed9,obfixed9,latxs)*100
	}
	civec_C9 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_C9[,j] <- quantile(dist_C9[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(latmodelfn(coef(modelfit9),sevfixed9,modfixed9,obfixed9,x)*100,15,49,n=length(latxs),add=TRUE,lwd=3,col="gray")
	points(latxs,civec_C9[1,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_C9[2,],type="l",col="gray",lty=cilinetype,lwd=cilinewidth)
}
if(mod8==TRUE){
	vmat_C8 <- mvrnorm(ndraws,mu=coef(modelfit8),Sigma=vcov(modelfit8))
	dist_C8 <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_C8[i,] <- latmodelfn(vmat_C8[i,],sevfixed8,modfixed8,obfixed8,latxs)*100
	}
	civec_C8 <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_C8[,j] <- quantile(dist_C8[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(latmodelfn(coef(modelfit8),sevfixed8,modfixed8,obfixed8,x)*100,15,49,n=length(latxs),add=TRUE,lwd=3,col="black")
	points(latxs,civec_C8[1,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_C8[2,],type="l",col="black",lty=cilinetype,lwd=cilinewidth)
}
if(sigmod==TRUE){
	vmat_sig <- mvrnorm(ndraws,mu=coef(sigfit),Sigma=vcov(sigfit))
	dist_sig <- array(dim=c(ndraws,length(latxs)))
	for(i in 1:ndraws){
		dist_sig[i,] <- sigmoid(vmat_sig[i,],sigfixed,latxs)*100
	}
	civec_sig <- array(dim=c(2,length(latxs)))
	for(j in 1:length(latxs)){
		civec_sig[,j] <- quantile(dist_sig[,j],c(lowb,upb),na.rm=TRUE)
	}

	curve(sigmoid(coef(sigfit),sigfixed,x)*100,15,49,add=TRUE,lwd=3,col="red")
	points(latxs,civec_sig[1,],type="l",col="red",lty=cilinetype,lwd=cilinewidth)
	points(latxs,civec_sig[2,],type="l",col="red",lty=cilinetype,lwd=cilinewidth)
}