% Menge_SuccessionDynamicsModel_FigB8_Script.m is the script that runs 
% the simulations for competing three different strategies against 
% each other in succession for a variety of psi values.  In the paper,
% note that gamma = psi * c, and here c is 120 per yr.

clear all

global p

for habitat=0:1
    p = Menge_SuccessionDynamicsModel_Pars_3();
    SevModNon = habitat; % 0 for Severely N-limited, 1 for Moderately N-limited
        
    % initial conditions

    t0 = 0; % [y]
    tstep = 0.1; % [y]
    tf = 400; % [y]
    if(SevModNon==0)
        B0 = [10 10 10]; % [kg C/ha], B(1) is facultative fixer, B(2) is obligate fixer, B(3) is non-fixer
        DN0 = 1;
        DP0 = 5;
        AN0 = 0.001;
        AP0 = 0.1;
    elseif(SevModNon==1)
        B0 = [1000 1000 1000]; % [kg C/ha], B(1) is fixer, B(2) is non-fixer
        DN0 = 50;
        DP0 = 5;
        AN0 = 1;
        AP0 = 0.1;
    end
    
    options=odeset('NonNegative',1:7);
      
    psis = (0.03:0.03:0.36)/p.c;
    swa_fia = zeros(3,length(psis)); % Succession-weighted abundance vectors (to be filled in later)
    swa_young = zeros(3,length(psis));
    swa_old = zeros(3,length(psis));
    for j=1:length(psis)
        i = 1;
        T = zeros(length(1/(tf/tstep)),1);
        X = zeros(length(1/(tf/tstep)),7);
        T(1) = t0;
        X(1,:) = [B0 DN0 DP0 AN0 AP0];
        ['habitat ',num2str(habitat+1),' of 2; psi ',num2str(j),' of ',num2str(length(psis))] %#ok<NOPTS>
        p.psi=psis(j);
        for curt = t0:tstep:tf-tstep
            curt %#ok<NOPTS>
            [Tshort Xshort] = ode45(@Menge_SuccessionDynamicsModel_odes_fac_ob_non, [curt curt+tstep], X(i,:), options);
            i = i+1;
            T(i) = Tshort(end);    % Update time
            X(i,:) = Xshort(end,:); % Update vars
            clear Tshort Xshort;
        end
        swa_fia(:,j) = Menge_SuccessionDynamicsModel_swa(1,T,X);
        swa_young(:,j) = Menge_SuccessionDynamicsModel_swa(2,T,X);
        swa_old(:,j) = Menge_SuccessionDynamicsModel_swa(3,T,X);
        if SevModNon==0
            save -v7.3 BNFsucc_data_fac_v_ob_v_non_severeNlim_psirange.mat
        elseif SevModNon==1
            save -v7.3 BNFsucc_data_fac_v_ob_v_non_moderateNlim_psirange.mat
        end
    end
end
Menge_SuccessionDynamicsModel_FigB8_Figure;