% Menge_SuccessionalDynamicsModel_Script.m is the script that runs the 
% simulations for competing different N-fixing and non-fixing strategies 
% against each other in succession.

clear all

global p

% parameters

p = Menge_SuccessionDynamicsModel_Pars();
SevModNon = 0; % 0 for Severely N-limited, 1 for Moderately N-limited
whichrun = 2; % 0 for obligate only, 1 for facultative only, 2 for both

% initial conditions for obligate run

t0 = 0; % [y]
tstep = 0.1; % [y]
tf = 400; % [y]
if(SevModNon==0)
    B0 = [10 10]; % [kg C/ha], B(1) is fixer, B(2) is non-fixer
    DN0 = 1;
    DP0 = 5;
    AN0 = 0.001;
    AP0 = 0.1;
elseif(SevModNon==1)
    B0 = [1000 1000]; % [kg C/ha], B(1) is fixer, B(2) is non-fixer
    DN0 = 50;
    DP0 = 5;
    AN0 = 1;
    AP0 = 0.1;
end

i = 1;
T = zeros(length(1/(tf/tstep)),1);
X = zeros(length(1/(tf/tstep)),6);
T(1) = t0;
X = [B0(1) B0(2) DN0 DP0 AN0 AP0];

options=odeset('NonNegative',1:6);

% simulation for obligate run

if(whichrun==0 || whichrun==2)
    for curt = t0:tstep:tf-tstep
        curt %#ok<NOPTS>
        [Tshort Xshort] = ode45(@Menge_SuccessionDynamicsModel_odes_ob_non, [curt curt+tstep], X(i,:), options);
        i = i+1;
        T(i) = Tshort(end);    % Update time
        X(i,:) = Xshort(end,:); % Update vars
        clear Tshort Xshort;
        if(SevModNon==0)
            save -v7.3 BNFsucc_data_obligate_v_non_severeNlim.mat
        elseif(SevModNon==1)
            save -v7.3 BNFsucc_data_obligate_v_non_moderateNlim.mat
        end
    end
end

% reset initial conditions for facultative run

i = 1;
T = zeros(length(1/(tf/tstep)),1);
X = zeros(length(1/(tf/tstep)),6);
T(1) = t0;
X = [B0(1) B0(2) DN0 DP0 AN0 AP0];

% simulation for facultative run

if(whichrun>0)
    for curt = t0:tstep:tf-tstep
        curt %#ok<NOPTS>
        [Tshort Xshort] = ode45(@Menge_SuccessionDynamicsModel_odes_fac_non, [curt curt+tstep], X(i,:), options);
        i = i+1;
        T(i) = Tshort(end);    % Update time
        X(i,:) = Xshort(end,:); % Update vars
        clear Tshort Xshort;
        if(SevModNon==0)
            save -v7.3 BNFsucc_data_facultative_v_non_severeNlim.mat
        elseif(SevModNon==1)
            save -v7.3 BNFsucc_data_facultative_v_non_moderateNlim.mat
        end
    end
end

Menge_SuccessionDynamicsModel_Figures